summaryrefslogtreecommitdiff
path: root/scene/animation
diff options
context:
space:
mode:
authorRĂ©mi Verschelde <rverschelde@gmail.com>2018-09-13 10:59:00 +0200
committerGitHub <noreply@github.com>2018-09-13 10:59:00 +0200
commit1a16dabfb52a5f3e82afa22ee827d8ed8f17511e (patch)
treed99eddbfc533a6ce37fde09d31f656ff31887dcb /scene/animation
parent9c0cc0db63f61cd71a2a735519dc7816973e5b7e (diff)
parent08bde5b2dea65ef3f80af5de4f4caf0e76982b64 (diff)
Merge pull request #21982 from luzpaz/misc-typos
Misc. typos
Diffstat (limited to 'scene/animation')
-rw-r--r--scene/animation/animation_node_state_machine.cpp2
-rw-r--r--scene/animation/animation_player.cpp2
-rw-r--r--scene/animation/animation_tree.cpp8
-rw-r--r--scene/animation/root_motion_view.cpp2
4 files changed, 7 insertions, 7 deletions
diff --git a/scene/animation/animation_node_state_machine.cpp b/scene/animation/animation_node_state_machine.cpp
index 837723450c..5923ad7657 100644
--- a/scene/animation/animation_node_state_machine.cpp
+++ b/scene/animation/animation_node_state_machine.cpp
@@ -320,7 +320,7 @@ float AnimationNodeStateMachinePlayback::process(AnimationNodeStateMachine *sm,
}
if (!_travel(sm, start_request)) {
- //cant travel, then teleport
+ //can't travel, then teleport
path.clear();
current = start_request;
}
diff --git a/scene/animation/animation_player.cpp b/scene/animation/animation_player.cpp
index 2a4d526a7f..7d91703cf8 100644
--- a/scene/animation/animation_player.cpp
+++ b/scene/animation/animation_player.cpp
@@ -419,7 +419,7 @@ void AnimationPlayer::_animation_process_animation(AnimationData *p_anim, float
if (first_key_time == 0.0) {
//ignore, use for transition
if (key_count == 1)
- continue; //with one key we cant do anything
+ continue; //with one key we can't do anything
transition = a->track_get_key_transition(i, 0);
first_key_time = a->track_get_key_time(i, 1);
first_key = 1;
diff --git a/scene/animation/root_motion_view.cpp b/scene/animation/root_motion_view.cpp
index 098bd05e9a..01a10dbc2b 100644
--- a/scene/animation/root_motion_view.cpp
+++ b/scene/animation/root_motion_view.cpp
@@ -112,7 +112,7 @@ void RootMotionView::_notification(int p_what) {
first = false;
- transform.orthonormalize(); //dont want scale, too imprecise
+ transform.orthonormalize(); //don't want scale, too imprecise
transform.affine_invert();
accumulated = transform * accumulated;
diff --git a/scene/animation/animation_tree.cpp b/scene/animation/animation_tree.cpp
index 7a4846e6d5..eb00f91bb3 100644
--- a/scene/animation/animation_tree.cpp
+++ b/scene/animation/animation_tree.cpp
@@ -192,7 +192,7 @@ float AnimationNode::_blend_node(const StringName &p_subpath, const Vector<Strin
case FILTER_IGNORE:
break; //will not happen anyway
case FILTER_PASS: {
//values filtered pass, the rest dont
for (int i = 0; i < blend_count; i++) {
if (blendw[i] == 0) //not filtered, does not pass
continue;
@@ -206,7 +206,7 @@ float AnimationNode::_blend_node(const StringName &p_subpath, const Vector<Strin
} break;
case FILTER_STOP: {
//values filtered dont pass, the rest are blended
for (int i = 0; i < blend_count; i++) {
if (blendw[i] > 0) //filtered, does not pass
@@ -292,7 +292,7 @@ String AnimationNode::get_caption() const {
}
void AnimationNode::add_input(const String &p_name) {
- //root nodes cant add inputs
+ //root nodes can't add inputs
ERR_FAIL_COND(Object::cast_to<AnimationRootNode>(this) != NULL)
Input input;
ERR_FAIL_COND(p_name.find(".") != -1 || p_name.find("/") != -1);
@@ -1227,7 +1227,7 @@ void AnimationTree::_process_graph(float p_delta) {
t->object->set_indexed(t->subpath, t->value);
} break;
- default: {} //the rest dont matter
+ default: {} //the rest don't matter
}
}
}
@@ -192,7 +192,7 @@ float AnimationNode::_blend_node(const StringName &p_subpath, const Vector<Strin
break; //will not happen anyway
case FILTER_PASS: {
- //values filtered pass, the rest dont
+ //values filtered pass, the rest don't
for (int i = 0; i < blend_count; i++) {
if (blendw[i] == 0) //not filtered, does not pass
@@ -206,7 +206,7 @@ float AnimationNode::_blend_node(const StringName &p_subpath, const Vector<Strin
} break;
case FILTER_STOP: {
- //values filtered dont pass, the rest are blended
+ //values filtered don't pass, the rest are blended
for (int i = 0; i < blend_count; i++) {
if (blendw[i] > 0) //filtered, does not pass